def buildSuffix = project.properties['build.suffix'] /* jira6 or jira7? */
def buildNumber = project.properties['build.number'] ?: System.properties['build.number'] /* set externally */
def buildRelease = project.properties['build.release'] /* set in "release" profile */
String[] targetVersionArray = targetVersions.split(';')

def version = project.version
def snapshot = project.version.endsWith('-SNAPSHOT')
if (snapshot) {
  version = version.substring(0, version.length() - 9)
}

def suffixes = []

def m = version =~ /^(.*)\.((rc|beta|hf|eap)\d*)$/
if (m) {
  version = m.group(1)
  suffixes << m.group(2)
}

if (!(version ==~ /\d+\.\d+\.\d+/)) {
  throw new AssertionError('\nBlocked by set-version execution: bad base version ' + version + '\n')
}

if (buildSuffix) {
  suffixes << buildSuffix
}
if (!buildRelease) {
  if (buildNumber && buildNumber != '0') {
    suffixes << buildNumber
  }
}
if (suffixes) {
  version += '.' + suffixes.join('-')
} else if (snapshot) {
  // Atlas-run and atlas-debug don't pick up project.build.finalName from this
  // script for some reason and try to load the JAR with the default finalName
  // of ${artifactId}-${version}.
  // Using version-SNAPSHOT so that finalName coincides with the default.
  version += '-SNAPSHOT'
}

println("===== setting project.version to $version =====")
project.version = version

def finalName = project.artifactId + '-' + version
println("===== setting project.build.finalName to $finalName =====")
project.build.finalName = finalName

for (String targetVersion: targetVersionArray) {
  project.properties[targetVersion] = version
}